==> sign-center-api-0.2.27-004-sources.jar: cn/com/duiba/sign/center/api/dto/signtreasure/SignTreasureCodeDetailDto.java <==
package cn.com.duiba.sign.center.api.dto.signtreasure;

import cn.com.duiba.sign.center.api.enums.signtreasure.ExchangeStatusEnum;
import cn.com.duiba.sign.center.api.enums.signtreasure.RewardStatusEnum;
import cn.com.duiba.sign.center.api.enums.signtreasure.TreasureOriginEnum;
import java.io.Serializable;

/**
 * @author liugq
 * @date created in 2019.5.5
 * @description: 
 */
public class SignTreasureCodeDetailDto implements Serializable {

    private static final long serialVersionUID = -943324495930033941L;
    /**
     * 主键id 
     **/
    private Long id;
    /** 
     * 应用id 
     **/
    private Long appId;
    /** 
     * 用户id 
     **/
    private Long consumerId;
    /** 
     * 开发者用户id 
     **/
    private String partnerUserId;
    /** 
     * 期次id 
     **/
    private Long phaseId;
    /** 
     * 开心码券码 
     **/
    private String treasureCode;
    /** 
     * 来源：0-签到 1-积分兑换 
     **/
    private TreasureOriginEnum origin;
    /** 
     * 状态: 1-待领奖 2-已领奖 
     **/
    private RewardStatusEnum rewardStatus;
    /** 
     * 获奖等级：0-未中奖 
     **/
    private Integer prizeLevel;
    /** 
     * 状态 0：购买处理中 1：购买成功 2：购买失败 
     **/
    private ExchangeStatusEnum orderStatus;
    /** 
     * 扣积分业务ID OR 签到logid
     **/
    private String bizId;


    public void setId(Long value) {
        this.id = value;
    }
    public Long getId() {
        return this.id;
    }
    
    public void setAppId(Long value) {
        this.appId = value;
    }
    public Long getAppId() {
        return this.appId;
    }
    
    public void setConsumerId(Long value) {
        this.consumerId = value;
    }
    public Long getConsumerId() {
        return this.consumerId;
    }
    
    public void setPartnerUserId(String value) {
        this.partnerUserId = value;
    }
    public String getPartnerUserId() {
        return this.partnerUserId;
    }
    
    public void setPhaseId(Long value) {
        this.phaseId = value;
    }
    public Long getPhaseId() {
        return this.phaseId;
    }
    
    public void setTreasureCode(String value) {
        this.treasureCode = value;
    }
    public String getTreasureCode() {
        return this.treasureCode;
    }
    
    public void setPrizeLevel(Integer value) {
        this.prizeLevel = value;
    }
    public Integer getPrizeLevel() {
        return this.prizeLevel;
    }

    public TreasureOriginEnum getOrigin() {
        return origin;
    }

    public void setOrigin(TreasureOriginEnum origin) {
        this.origin = origin;
    }

    public RewardStatusEnum getRewardStatus() {
        return rewardStatus;
    }

    public void setRewardStatus(RewardStatusEnum rewardStatus) {
        this.rewardStatus = rewardStatus;
    }

    public ExchangeStatusEnum getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(ExchangeStatusEnum orderStatus) {
        this.orderStatus = orderStatus;
    }

    public void setBizId(String value) {
        this.bizId = value;
    }
    public String getBizId() {
        return this.bizId;
    }

    
    
}

==> sign-center-api-0.3.7-sources.jar: cn/com/duiba/sign/center/api/dto/signtreasure/SignTreasureCodeDetailDto.java <==
package cn.com.duiba.sign.center.api.dto.signtreasure;

import cn.com.duiba.sign.center.api.enums.signtreasure.ExchangeStatusEnum;
import cn.com.duiba.sign.center.api.enums.signtreasure.RewardStatusEnum;
import cn.com.duiba.sign.center.api.enums.signtreasure.TreasureOriginEnum;
import java.io.Serializable;

/**
 * @author liugq
 * @date created in 2019.5.5
 * @description: 
 */
public class SignTreasureCodeDetailDto implements Serializable {

    private static final long serialVersionUID = -943324495930033941L;
    /**
     * 主键id 
     **/
    private Long id;
    /** 
     * 应用id 
     **/
    private Long appId;
    /** 
     * 用户id 
     **/
    private Long consumerId;
    /** 
     * 开发者用户id 
     **/
    private String partnerUserId;
    /** 
     * 期次id 
     **/
    private Long phaseId;
    /** 
     * 开心码券码 
     **/
    private String treasureCode;
    /** 
     * 来源：0-签到 1-积分兑换 
     **/
    private TreasureOriginEnum origin;
    /** 
     * 状态: 1-待领奖 2-已领奖 
     **/
    private RewardStatusEnum rewardStatus;
    /** 
     * 获奖等级：0-未中奖 
     **/
    private Integer prizeLevel;
    /**
     * 期次奖品主键：中奖情况下
     */
    private Long prizeOptionId;
    /** 
     * 状态 0：购买处理中 1：购买成功 2：购买失败 
     **/
    private ExchangeStatusEnum orderStatus;
    /** 
     * 扣积分业务ID OR 签到logid
     **/
    private String bizId;


    public void setId(Long value) {
        this.id = value;
    }
    public Long getId() {
        return this.id;
    }
    
    public void setAppId(Long value) {
        this.appId = value;
    }
    public Long getAppId() {
        return this.appId;
    }
    
    public void setConsumerId(Long value) {
        this.consumerId = value;
    }
    public Long getConsumerId() {
        return this.consumerId;
    }
    
    public void setPartnerUserId(String value) {
        this.partnerUserId = value;
    }
    public String getPartnerUserId() {
        return this.partnerUserId;
    }
    
    public void setPhaseId(Long value) {
        this.phaseId = value;
    }
    public Long getPhaseId() {
        return this.phaseId;
    }
    
    public void setTreasureCode(String value) {
        this.treasureCode = value;
    }
    public String getTreasureCode() {
        return this.treasureCode;
    }
    
    public void setPrizeLevel(Integer value) {
        this.prizeLevel = value;
    }
    public Integer getPrizeLevel() {
        return this.prizeLevel;
    }

    public TreasureOriginEnum getOrigin() {
        return origin;
    }

    public void setOrigin(TreasureOriginEnum origin) {
        this.origin = origin;
    }

    public RewardStatusEnum getRewardStatus() {
        return rewardStatus;
    }

    public void setRewardStatus(RewardStatusEnum rewardStatus) {
        this.rewardStatus = rewardStatus;
    }

    public ExchangeStatusEnum getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(ExchangeStatusEnum orderStatus) {
        this.orderStatus = orderStatus;
    }

    public void setBizId(String value) {
        this.bizId = value;
    }
    public String getBizId() {
        return this.bizId;
    }

    public Long getPrizeOptionId() {
        return prizeOptionId;
    }

    public void setPrizeOptionId(Long prizeOptionId) {
        this.prizeOptionId = prizeOptionId;
    }
}
